<?php
/*
 * This file is part of the MagmaCore package.
 *
 * (c) Ricardo Miller <ricardomiller@lava-studio.co.uk>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace MagmaCore\PanelMenu\MenuItems;

use MagmaCore\PanelMenu\MenuItems\MenuItemEntity;
use MagmaCore\Base\AbstractBaseModel;
use MagmaCore\Base\Exception\BaseInvalidArgumentException;

class MenuItemModel extends AbstractBaseModel
{

    /** @var string */
    protected const TABLESCHEMA = 'menu_items';
    /** @var string */
    protected const TABLESCHEMAID = 'id';
    /** @var array */
    protected const COLUMN_STATUS = [];

    /**
     * Main constructor class which passes the relevant information to the
     * base model parent constructor. This allows the repository to fetch the
     * correct information from the database based on the model/entity
     *
     * @return void
     * @throws BaseInvalidArgumentException
     */
    public function __construct()
    {
        parent::__construct(self::TABLESCHEMA, self::TABLESCHEMAID, MenuItemEntity::class);
    }

    /**
     * Guard these IDs from being deleted etc..
     *
     * @return array
     */
    public function guardedID(): array
    {
        return [
        ];
    }

    /**
     * Return an array of column values if table supports the column field
     *
     * @return array
     */
    public function getColumnStatus(): array
    {
        return self::COLUMN_STATUS;
    }

    /**
     * @param $id
     * @return mixed
     */
    public function getNameForSelectField($id): mixed
    {
        $name = $this->getRepo()->findObjectBy(['id' => $id], ['item_label']);
        return $name->item_label;
    }

}
